@@ -12,6 +12,7 @@ use crate::{
 };
 use anyhow::{anyhow, Result};
 
+#[allow(clippy::large_enum_variant)]
 #[derive(Debug, StructOpt)]
 pub enum ConfigArgs {
     #[structopt(name = "add")]
@@ -102,7 +103,7 @@ pub fn run(
                         "No"
                     },
                     if *tokens {
-                        context.token.clone().unwrap_or_else(String::new)
+                        context.token.clone().unwrap_or_default()
                     } else {
                         "<Hidden>".into()
                     },
